#include <iostream>
#include <vector>
#include <memory>

class Shape {
public:
    virtual void draw() = 0;
    virtual ~Shape() {}
};

class Circle : public Shape {
public:
    void draw() override { std::cout << "Drawing Circle" << std::endl; }
};

class Square : public Shape {
public:
    void draw() override { std::cout << "Drawing Square" << std::endl; }
};

int main() {
    std::vector<std::unique_ptr<Shape>> shapes;
    shapes.push_back(std::make_unique<Circle>());
    shapes.push_back(std::make_unique<Square>());
    shapes.push_back(std::make_unique<Circle>());

    for (const auto& shape : shapes) {
        shape->draw();

        if (dynamic_cast<Circle*>(shape.get())) {
            std::cout << "This is a Circle" << std::endl;
        } else if (dynamic_cast<Square*>(shape.get())) {
            std::cout << "This is a Square" << std::endl;
        }
    }

    return 0;
}
